Exception: OEmbed::Error
- Inherits:
-
StandardError
- Object
- StandardError
- OEmbed::Error
- Defined in:
- lib/oembed/errors.rb
Overview
A generic OEmbed-related Error. The OEmbed library does its best to capture all internal errors and wrap them in an OEmbed::Error class so that the error-handling code in your application can more easily identify the source of errors.
The following Classes inherit from OEmbed::Error
- OEmbed::FormatNotSupported
- OEmbed::NotFound
- OEmbed::ParseError
- OEmbed::UnknownFormat
- OEmbed::UnknownResponse
Direct Known Subclasses
FormatNotSupported, NotFound, ParseError, UnknownFormat, UnknownResponse